"use strict";
// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var widgets_1 = require("@phosphor/widgets");
var React = require("react");
var ReactDOM = require("react-dom");
var Plotly = require("plotly.js/dist/plotly");
var component_1 = require("./component");
require("../style/index.css");
/**
 * The CSS class to add to the Plotly Editor Widget.
 */
var CSS_CLASS = 'jp-RenderedPlotlyEditor';
/**
 * The CSS class for a Plotly Editor icon.
 */
var CSS_ICON_CLASS = 'jp-MaterialIcon jp-PlotlyIcon';
/**
 * The MIME type for Plotly Editor.
 */
exports.MIME_TYPE = 'application/vnd.plotly-editor.v1+json';
var RenderedPlotlyEditor = /** @class */ (function (_super) {
    __extends(RenderedPlotlyEditor, _super);
    /**
     * Create a new widget for rendering Plotly Editor.
     */
    function RenderedPlotlyEditor(options) {
        var _this = _super.call(this) || this;
        _this.addClass(CSS_CLASS);
        _this._mimeType = options.mimeType;
        return _this;
    }
    /**
     * Dispose of the resources used by the widget.
     */
    RenderedPlotlyEditor.prototype.dispose = function () {
        ReactDOM.unmountComponentAtNode(this.node);
        _super.prototype.dispose.call(this);
    };
    /**
     * Render Plotly Editor into this widget's node.
     */
    RenderedPlotlyEditor.prototype.renderModel = function (model) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            var state = model.data[_this._mimeType];
            try {
                var handleUpdate = function (state) {
                    var newData = (_a = {},
                        _a[_this._mimeType] = state,
                        _a);
                    model.setData({ data: newData });
                    var _a;
                };
                _this._ref = ReactDOM.render(React.createElement(component_1.default, { state: state, handleUpdate: handleUpdate, plotly: Plotly }), _this.node, function () {
                    resolve(undefined);
                });
            }
            catch (error) {
                reject(error);
            }
        });
    };
    /**
     * A message handler invoked on a `'resize'` message.
     */
    RenderedPlotlyEditor.prototype.onResize = function (msg) {
        this.update();
    };
    /**
     * A message handler invoked on an `'update-request'` message.
     */
    RenderedPlotlyEditor.prototype.onUpdateRequest = function () {
        if (this.isVisible && this._ref) {
            this._ref.handleResize();
        }
    };
    return RenderedPlotlyEditor;
}(widgets_1.Widget));
exports.RenderedPlotlyEditor = RenderedPlotlyEditor;
/**
 * A mime renderer factory for Plotly Editor.
 */
exports.rendererFactory = {
    safe: true,
    mimeTypes: [exports.MIME_TYPE],
    createRenderer: function (options) { return new RenderedPlotlyEditor(options); }
};
var extensions = [
    {
        id: 'jupyterlab-chart-editor:factory',
        name: 'jupyterlab-chart-editor:factory',
        rendererFactory: exports.rendererFactory,
        rank: 0,
        dataType: 'json',
        fileTypes: [
            {
                name: 'plotlyeditor',
                mimeTypes: [exports.MIME_TYPE],
                extensions: ['.plotly', '.plotly.json'],
                iconClass: CSS_ICON_CLASS
            }
        ],
        documentWidgetFactoryOptions: {
            name: 'Plotly Editor',
            primaryFileType: 'plotlyeditor',
            // The 'plotly' type is defined in @jupyterlab/plotly-extension
            fileTypes: ['plotly', 'plotlyeditor', 'json'],
            defaultFor: ['plotlyeditor']
        }
    }
];
exports.default = extensions;
